searchNodes=[{"doc":"NimbleCSV is a small and fast parsing and dumping library.It works by building highly-inlined CSV parsers, designed to work with strings, enumerables and streams. At the top of your file (and not inside a function), you can define your own parser module:NimbleCSV.define(MyParser, separator: &quot;\\t&quot;, escape: &quot;\\&quot;&quot;)Once defined, we can parse data accordingly:iex&gt; MyParser.parse_string &quot;name\\tage\\njohn\\t27&quot; [[&quot;john&quot;,&quot;27&quot;]]See the define/2 function for the list of functions that would be defined in MyParser.ParsingNimbleCSV is by definition restricted in scope to do only parsing (and dumping). For example, the example above discarded the headers when parsing the string, as NimbleCSV expects developers to handle those explicitly later. For example:&quot;name\\tage\\njohn\\t27&quot; |&gt; MyParser.parse_string |&gt; Enum.map(fn [name, age] -&gt; %{name: name, age: String.to_integer(age)} end)This is particularly useful with the parse_stream functionality that receives and returns a stream. For example, we can use it to parse files line by line lazily:&quot;path/to/csv/file&quot; |&gt; File.stream!(read_ahead: 100_000) |&gt; MyParser.parse_stream |&gt; Stream.map(fn [name, age] -&gt; %{name: :binary.copy(name), age: String.to_integer(age)} end) |&gt; Stream.runBy default this library ships with two implementations:NimbleCSV.RFC4180, which is the most common implementation of CSV parsing/dumping available using comma as separators and double-quote as escape. If you want to use it in your codebase, simply alias it to CSV and enjoy:iex&gt; alias NimbleCSV.RFC4180, as: CSV iex&gt; CSV.parse_string &quot;name,age\\njohn,27&quot; [[&quot;john&quot;,&quot;27&quot;]]NimbleCSV.Spreadsheet, which uses UTF-16 and is most commonly used by spreadsheet software, such as Excel, Numbers, etc.Binary referencesOne of the reasons behind NimbleCSV performance is that it performs parsing by matching on binaries and extracting those fields as binary references. Therefore if you have a row such as:one,two,three,four,fiveNimbleCSV will return a list of [&quot;one&quot;, &quot;two&quot;, &quot;three&quot;, &quot;four&quot;, &quot;five&quot;] where each element references the original row. For this reason, if you plan to keep the parsed data around in the parsing process or even send it to another process, you must copy the data before doing the transfer, that's why we use :binary.copy/1 in the examples above.DumpingNimbleCSV can dump any enumerable to either iodata or to streams:iex&gt; IO.iodata_to_binary MyParser.dump_to_iodata([~w(name age), ~w(mary 28)]) &quot;name\\tage\\nmary\\t28\\n&quot; iex&gt; MyParser.dump_to_stream([~w(name age), ~w(mary 28)]) #Stream&lt;...&gt;","ref":"NimbleCSV.html","title":"NimbleCSV","type":"behaviour"},{"doc":"Defines a new parser/dumper.Calling this function defines a CSV module. Therefore, define is typically invoked at the top of your files and not inside functions. Placing it inside a function would cause the same module to be defined multiple times, one time per invocation, leading your code to emit warnings and slowing down execution.It accepts the following options::moduledoc - the documentation for the generated moduleThe following options control parsing::escape- the CSV escape, defaults to &quot;\\&quot;&quot;:encoding - converts the given data from encoding to UTF-8:separator- the CSV separators, defaults to &quot;,&quot;. It can be a string or a list of strings. If a list is given, the first entry is used for dumping (see below):newlines - the list of entries to be considered newlines when parsing, defaults to [&quot;\\r\\n&quot;, &quot;\\n&quot;] (note they are attempted in order, so the order matters):trim_bom - automatically trims BOM (byte-order marker) when parsing string. Note the bom is not trimmed for enumerables or streams. In such cases, the BOM must be trimmed directly in the stream, such as File.stream!(path, [:trim_bom])The following options control dumping::escape- the CSV escape character, defaults to &quot;\\&quot;&quot;:encoding - converts the given data from UTF-8 to the given encoding:separator- the CSV separator character, defaults to &quot;,&quot;:line_separator - the CSV line separator character, defaults to &quot;\\n&quot;:dump_bom - includes BOM (byte order marker) in the dumped document:reserved - the list of characters to be escaped, it defaults to the :separator, :line_separator and :escape characters above.Although parsing may support multiple newline delimiters, when dumping only one of them must be picked, which is controlled by the :line_separator option. This allows NimbleCSV to handle both &quot;\\r\\n&quot; and &quot;\\n&quot; when parsing, but only the latter for dumping.Parser/Dumper APIModules defined with define/2 implement the NimbleCSV behaviour. See the callbacks for this behaviour for information on the generated functions and their documentation.","ref":"NimbleCSV.html#define/2","title":"NimbleCSV.define/2","type":"function"},{"doc":"Eagerly dumps an enumerable into iodata (a list of binaries and bytes and other lists).","ref":"NimbleCSV.html#c:dump_to_iodata/1","title":"NimbleCSV.dump_to_iodata/1","type":"callback"},{"doc":"Lazily dumps from an enumerable to a stream.It returns a stream that emits each row as iodata.","ref":"NimbleCSV.html#c:dump_to_stream/1","title":"NimbleCSV.dump_to_stream/1","type":"callback"},{"doc":"Same as parse_enumerable(enumerable, []).","ref":"NimbleCSV.html#c:parse_enumerable/1","title":"NimbleCSV.parse_enumerable/1","type":"callback"},{"doc":"Eagerly parses CSV from an enumerable and returns a list of rows.Options:skip_headers - when true, skips headers. Defaults to true. Set it to false to keep headers or when the CSV has no headers.","ref":"NimbleCSV.html#c:parse_enumerable/2","title":"NimbleCSV.parse_enumerable/2","type":"callback"},{"doc":"Same as parse_stream(enumerable, []).","ref":"NimbleCSV.html#c:parse_stream/1","title":"NimbleCSV.parse_stream/1","type":"callback"},{"doc":"Lazily parses CSV from a stream and returns a stream of rows.It expects the given enumerable to be line-oriented, where each entry in the enumerable is a line.Options:skip_headers - when true, skips headers. Defaults to true. Set it to false to keep headers or when the CSV has no headers.","ref":"NimbleCSV.html#c:parse_stream/2","title":"NimbleCSV.parse_stream/2","type":"callback"},{"doc":"Same as parse_string(enumerable, []).","ref":"NimbleCSV.html#c:parse_string/1","title":"NimbleCSV.parse_string/1","type":"callback"},{"doc":"Eagerly parses CSV from a string and returns a list of rows.Options:skip_headers - when true, skips headers. Defaults to true. Set it to false to keep headers or when the CSV has no headers.","ref":"NimbleCSV.html#c:parse_string/2","title":"NimbleCSV.parse_string/2","type":"callback"},{"doc":"A CSV parser that uses comma as separator and double-quotes as escape according to RFC4180.","ref":"NimbleCSV.RFC4180.html","title":"NimbleCSV.RFC4180","type":"module"},{"doc":"Callback implementation for NimbleCSV.dump_to_iodata/1.","ref":"NimbleCSV.RFC4180.html#dump_to_iodata/1","title":"NimbleCSV.RFC4180.dump_to_iodata/1","type":"function"},{"doc":"Callback implementation for NimbleCSV.dump_to_stream/1.","ref":"NimbleCSV.RFC4180.html#dump_to_stream/1","title":"NimbleCSV.RFC4180.dump_to_stream/1","type":"function"},{"doc":"Callback implementation for NimbleCSV.parse_enumerable/2.","ref":"NimbleCSV.RFC4180.html#parse_enumerable/2","title":"NimbleCSV.RFC4180.parse_enumerable/2","type":"function"},{"doc":"Callback implementation for NimbleCSV.parse_stream/2.","ref":"NimbleCSV.RFC4180.html#parse_stream/2","title":"NimbleCSV.RFC4180.parse_stream/2","type":"function"},{"doc":"Callback implementation for NimbleCSV.parse_string/2.","ref":"NimbleCSV.RFC4180.html#parse_string/2","title":"NimbleCSV.RFC4180.parse_string/2","type":"function"},{"doc":"A parser with spreadsheet friendly settings.The parser uses tab as separator and double-quotes as escape, as required by common spreadsheet software such as Excel, Numbers and OpenOffice. It's encoded in UTF-16 little-endian with a byte-order BOM.","ref":"NimbleCSV.Spreadsheet.html","title":"NimbleCSV.Spreadsheet","type":"module"},{"doc":"Callback implementation for NimbleCSV.dump_to_iodata/1.","ref":"NimbleCSV.Spreadsheet.html#dump_to_iodata/1","title":"NimbleCSV.Spreadsheet.dump_to_iodata/1","type":"function"},{"doc":"Callback implementation for NimbleCSV.dump_to_stream/1.","ref":"NimbleCSV.Spreadsheet.html#dump_to_stream/1","title":"NimbleCSV.Spreadsheet.dump_to_stream/1","type":"function"},{"doc":"Callback implementation for NimbleCSV.parse_enumerable/2.","ref":"NimbleCSV.Spreadsheet.html#parse_enumerable/2","title":"NimbleCSV.Spreadsheet.parse_enumerable/2","type":"function"},{"doc":"Callback implementation for NimbleCSV.parse_stream/2.","ref":"NimbleCSV.Spreadsheet.html#parse_stream/2","title":"NimbleCSV.Spreadsheet.parse_stream/2","type":"function"},{"doc":"Callback implementation for NimbleCSV.parse_string/2.","ref":"NimbleCSV.Spreadsheet.html#parse_string/2","title":"NimbleCSV.Spreadsheet.parse_string/2","type":"function"},{"doc":"","ref":"NimbleCSV.ParseError.html","title":"NimbleCSV.ParseError","type":"exception"}]